@@ -59,11 +59,17 @@ async def create_queues(queues, channel):
         )
         await dlq.bind(dlx_name, routing_key='#')
 
+        q_args = queue.get("arguments", {})
         if queue.get('x-dead-letter-exchange', dlx_name):
             q_args = {
                 **q_args,
                 **{"x-dead-letter-exchange": queue.get('x-dead-letter-exchange', dlx_name)}
             }
+        if queue.get('type', dlx_name):
+            q_args = {
+                **q_args,
+                **{"x-queue-type": queue.get('type', "quorum")}
+            }
 
         q_conns[queue['name']] = await channel.declare_queue(
             queue['name'],
